@@ -1,3 +1,4 @@
+from controller import Emitter
 from flockai.PyCatascopia.probelib.ProcessProbe import ProcessProbe
 from flockai.models.drones.autopilot_controlled_drone import AutopilotControlledDrone
 from flockai.models.drones.keyboard_controller_drone import KeyboardControlledDrone
@@ -136,7 +137,7 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
             # print("Transmit time:", transmit_time)
 
             # Receive messages
-            received_messages, receive_time = self.receive_msgs(receiver_devices)
+            # received_messages, receive_time = self.receive_msgs(receiver_devices)
             # print("Receive time:", receive_time)
 
             flight_time = probe_alive_time.get_val()
